pub struct ProblemClassificationProperties {
pub display_name: Option<String>,
pub secondary_consent_enabled: Vec<SecondaryConsentEnabled>,
}Expand description
Details about a problem classification available for an Azure service.
Fields
display_name: Option<String>Localized name of problem classification.
secondary_consent_enabled: Vec<SecondaryConsentEnabled>This property indicates whether secondary consent is present for problem classification
Implementations